@@ -88,15 +88,19 @@ theme_dir = function(...) {
 # search for archetypes under the theme dir and all imported modules
 archetypes = function() {
   if (length(a <- theme_flag()) != 4) return()
-  d = unlist(lapply(load_config()[['module']][['imports']], function(x) {
-    if (is.character(p <- x[['path']])) p
-  }))
+  d = module_paths()
   d = file.path(a[2], c(a[4], d), 'archetypes')
   d = c('archetypes', d)
   d = dir(d, full.names = TRUE)
   paste0(basename(d), ifelse(utils::file_test('-d', d), '/', ''))
 }
 
+module_paths = function() {
+  unlist(lapply(load_config()[['module']][['imports']], function(x) {
+    if (is.character(p <- x[['path']])) p
+  }))
+}
+
 change_config = function(name, value) {
   f = find_config()
   x = read_utf8(f)
@@ -431,7 +435,16 @@ install_theme = function(
       remove_config()
       # remove the themesDir setting; it is unlikely that you need it
       change_config('themesDir', NA)
+      # read module:imports:path from config
+      mods = module_paths()
     })
+    mods = mods[!dir_exists(mods)]
+    # in case any modules are not downloaded, try to download them
+    if (length(mods)) {
+      tmpmod = tempfile(fileext = '.mod')
+      write_utf8(paste(mods, 'v1'), tmpmod)  # dirty hack
+      download_modules(tmpmod)
+    }
   })
   if (is_theme) if (update_config) {
     change_config('theme', sprintf('"%s"', theme))
